@@ -9,10 +9,10 @@ from os import sep
 from pathlib import Path
 from time import sleep, perf_counter
 from typing import Union, List, Any, Tuple
-from urllib.parse import quote
 
 from selenium.common.exceptions import NoAlertPresentException
 from selenium.webdriver.chrome.webdriver import WebDriver
+from selenium.webdriver.remote.webdriver import WebDriver as RemoteWebDriver
 from selenium.webdriver.remote.webelement import WebElement
 from selenium.webdriver.support.wait import WebDriverWait
 
@@ -25,7 +25,7 @@ from .session_element import make_session_ele, SessionElement
 class DriverPage(BasePage):
     """DriverPage封装了页面操作的常用功能，使用selenium来获取、解析、操作网页"""
 
-    def __init__(self, driver: WebDriver, timeout: float = 10) -> None:
+    def __init__(self, driver: RemoteWebDriver, timeout: float = 10) -> None:
         """初始化函数，接收一个WebDriver对象，用来操作网页"""
         super().__init__(timeout)
         self._driver = driver
@@ -74,15 +74,8 @@ class DriverPage(BasePage):
         :param interval: 重试间隔（秒）
         :return: 目标url是否可用，返回None表示不确定
         """
-        to_url = quote(url, safe='/:&?=%;#@+!')
-        retry = retry if retry is not None else self.retry_times
-        interval = interval if interval is not None else self.retry_interval
-
-        if not url:
-            raise ValueError('没有传入url。')
-
-        self._url = to_url
-        self._url_available = self._try_to_connect(to_url, times=retry, interval=interval, show_errmsg=show_errmsg)
+        retry, interval = self._before_connect(url, retry, interval)
+        self._url_available = self._d_connect(self._url, times=retry, interval=interval, show_errmsg=show_errmsg)
 
         try:
             self._driver.execute_script('Object.defineProperty(navigator,"webdriver",{get:() => undefined,});')
@@ -172,11 +165,11 @@ class DriverPage(BasePage):
         self._timeout = second
         self._wait_object = None
 
-    def _try_to_connect(self,
-                        to_url: str,
-                        times: int = 0,
-                        interval: float = 1,
-                        show_errmsg: bool = False) -> Union[bool, None]:
+    def _d_connect(self,
+                   to_url: str,
+                   times: int = 0,
+                   interval: float = 1,
+                   show_errmsg: bool = False) -> Union[bool, None]:
         """尝试连接，重试若干次                            \n
         :param to_url: 要访问的url
         :param times: 重试次数
@@ -302,7 +295,7 @@ class DriverPage(BasePage):
         """等待元素从dom删除、显示、隐藏                             \n
         :param loc_or_ele: 可以是元素、查询字符串、loc元组
         :param timeout: 等待超时时间
-        :return: 等待是否成功
+        :return: 用于等待的ElementWaiter对象
         """
         return ElementWaiter(self, loc_or_ele, timeout)
 
@@ -462,10 +455,10 @@ class DriverPage(BasePage):
         """
         return glob(f'{download_path}{sep}*.crdownload')
 
-    def process_alert(self, mode: str = 'ok', text: str = None, timeout: float = None) -> Union[str, None]:
+    def process_alert(self, ok: bool = True, send: str = None, timeout: float = None) -> Union[str, None]:
         """处理提示框                                                            \n
-        :param mode: 'ok' 或 'cancel'，若输入其它值，不会按按钮但依然返回文本值
-        :param text: 处理prompt提示框时可输入文本
+        :param ok: True表示确认，False表示取消，其它值不会按按钮但依然返回文本值
+        :param send: 处理prompt提示框时可输入文本
         :param timeout: 等待提示框出现的超时时间
         :return: 提示框内容文本，未等到提示框则返回None
         """
@@ -479,23 +472,23 @@ class DriverPage(BasePage):
         timeout = timeout if timeout is not None else self.timeout
         t1 = perf_counter()
         alert = do_it()
-        while not alert and perf_counter() - t1 <= timeout:
+        while alert is False and perf_counter() - t1 <= timeout:
             alert = do_it()
 
-        if not alert:
+        if alert is False:
             return None
 
-        if text:
-            alert.send_keys(text)
+        res_text = alert.text
 
-        text = alert.text
+        if send is not None:
+            alert.send_keys(send)
 
-        if mode == 'cancel':
-            alert.dismiss()
-        elif mode == 'ok':
+        if ok is True:
             alert.accept()
+        elif ok is False:
+            alert.dismiss()
 
-        return text
+        return res_text
 
 
 class ToFrame(object):
