@@ -12,7 +12,7 @@ from selenium.webdriver.remote.webelement import WebElement
 from .base import BaseElement
 from .common import get_loc
 from .driver_element import make_driver_ele, DriverElement
-from .session_element import make_session_ele
+from .session_element import make_session_ele, SessionElement
 
 
 class ShadowRootElement(BaseElement):
@@ -27,7 +27,7 @@ class ShadowRootElement(BaseElement):
 
     def __call__(self,
                  loc_or_str: Union[Tuple[str, str], str],
-                 timeout: float = None) -> Union[DriverElement, List[DriverElement], str]:
+                 timeout: float = None) -> Union[DriverElement, str, None]:
         """在内部查找元素                                            \n
         例：ele2 = ele1('@id=ele_id')                               \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
@@ -72,7 +72,9 @@ class ShadowRootElement(BaseElement):
 
         return self.parent_ele.ele(loc, timeout=0)
 
-    def next(self, index: int = 1, filter_loc: Union[tuple, str] = '') -> DriverElement:
+    def next(self,
+             index: int = 1,
+             filter_loc: Union[tuple, str] = '') -> Union[DriverElement, str, None]:
         """返回后面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个        \n
         :param index: 第几个查询结果元素
         :param filter_loc: 用于筛选元素的查询语法
@@ -81,7 +83,28 @@ class ShadowRootElement(BaseElement):
         nodes = self.nexts(filter_loc=filter_loc)
         return nodes[index - 1] if nodes else None
 
-    def nexts(self, filter_loc: Union[tuple, str] = '') -> List[DriverElement]:
+    def before(self,
+               index: int = 1,
+               filter_loc: Union[tuple, str] = '') -> Union[DriverElement, str, None]:
+        """返回前面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个        \n
+        :param index: 前面第几个查询结果元素
+        :param filter_loc: 用于筛选元素的查询语法
+        :return: 本元素前面的某个元素或节点
+        """
+        nodes = self.befores(filter_loc=filter_loc)
+        return nodes[index - 1] if nodes else None
+
+    def after(self, index: int = 1,
+              filter_loc: Union[tuple, str] = '') -> Union[DriverElement, str, None]:
+        """返回后面的一个兄弟元素，可用查询语法筛选，可指定返回筛选结果的第几个        \n
+        :param index: 后面第几个查询结果元素
+        :param filter_loc: 用于筛选元素的查询语法
+        :return: 本元素后面的某个元素或节点
+        """
+        nodes = self.afters(filter_loc=filter_loc)
+        return nodes[index - 1] if nodes else None
+
+    def nexts(self, filter_loc: Union[tuple, str] = '') -> List[Union[DriverElement, str]]:
         """返回后面所有兄弟元素或节点组成的列表        \n
         :param filter_loc: 用于筛选元素的查询语法
         :return: DriverElement对象组成的列表
@@ -94,9 +117,32 @@ class ShadowRootElement(BaseElement):
         xpath = f'xpath:./{loc}'
         return self.parent_ele.eles(xpath, timeout=0.1)
 
+    def befores(self, filter_loc: Union[tuple, str] = '') -> List[Union[DriverElement, str]]:
+        """返回后面全部兄弟元素或节点组成的列表，可用查询语法筛选        \n
+        :param filter_loc: 用于筛选元素的查询语法
+        :return: 本元素前面的元素或节点组成的列表
+        """
+        loc = get_loc(filter_loc, True)
+        if loc[0] == 'css selector':
+            raise ValueError('此css selector语法不受支持，请换成xpath。')
+
+        loc = loc[1].lstrip('./')
+        xpath = f'xpath:./preceding::{loc}'
+        return self.parent_ele.eles(xpath, timeout=0.1)
+
+    def afters(self, filter_loc: Union[tuple, str] = '') -> List[Union[DriverElement, str]]:
+        """返回前面全部兄弟元素或节点组成的列表，可用查询语法筛选        \n
+        :param filter_loc: 用于筛选元素的查询语法
+        :return: 本元素后面的元素或节点组成的列表
+        """
+        eles1 = self.nexts(filter_loc)
+        loc = get_loc(filter_loc, True)[1].lstrip('./')
+        xpath = f'xpath:./following::{loc}'
+        return eles1 + self.parent_ele.eles(xpath, timeout=0.1)
+
     def ele(self,
             loc_or_str: Union[Tuple[str, str], str],
-            timeout: float = None) -> Union[DriverElement, List[DriverElement]]:
+            timeout: float = None) -> Union[DriverElement, str, None]:
         """返回当前元素下级符合条件的第一个元素，默认返回                                   \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 查找元素超时时间，默认与元素所在页面等待时间一致
@@ -106,7 +152,7 @@ class ShadowRootElement(BaseElement):
 
     def eles(self,
              loc_or_str: Union[Tuple[str, str], str],
-             timeout: float = None) -> List[DriverElement]:
+             timeout: float = None) -> List[Union[DriverElement, str]]:
         """返回当前元素下级所有符合条件的子元素                                              \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 查找元素超时时间，默认与元素所在页面等待时间一致
@@ -114,14 +160,14 @@ class ShadowRootElement(BaseElement):
         """
         return self._ele(loc_or_str, timeout=timeout, single=False)
 
-    def s_ele(self, loc_or_ele=None):
+    def s_ele(self, loc_or_ele=None) -> Union[SessionElement, str, None]:
         """查找第一个符合条件的元素以SessionElement形式返回，处理复杂页面时效率很高                 \n
         :param loc_or_ele: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象或属性、文本
         """
         return make_session_ele(self, loc_or_ele)
 
-    def s_eles(self, loc_or_ele):
+    def s_eles(self, loc_or_ele) -> List[Union[SessionElement, str]]:
         """查找所有符合条件的元素以SessionElement列表形式返回，处理复杂页面时效率很高                 \n
         :param loc_or_ele: 元素的定位信息，可以是loc元组，或查询字符串
         :return: SessionElement对象或属性、文本
@@ -131,7 +177,7 @@ class ShadowRootElement(BaseElement):
     def _ele(self,
              loc_or_str: Union[Tuple[str, str], str],
              timeout: float = None,
-             single: bool = True) -> Union[DriverElement, List[DriverElement]]:
+             single: bool = True) -> Union[DriverElement, str, None, List[Union[DriverElement, str]]]:
         """返回当前元素下级符合条件的子元素，默认返回第一个                                                    \n
         :param loc_or_str: 元素的定位信息，可以是loc元组，或查询字符串
         :param timeout: 查找元素超时时间
@@ -180,49 +226,3 @@ class ShadowRootElement(BaseElement):
 
         except Exception:
             return False
-
-    # ----------------ShadowRootElement独有方法-----------------------
-    def _find_eles_by_text(self,
-                           text: str,
-                           tag: str = '',
-                           match: str = 'exact',
-                           single: bool = True) -> Union[DriverElement, List[DriverElement]]:
-        """根据文本获取页面元素                               \n
-        :param text: 文本字符串
-        :param tag: tag name
-        :param match: 'exact' 或 'fuzzy'，对应精确或模糊匹配
-        :param single: True则返回第一个，False则返回全部
-        :return: 返回DriverElement对象或组成的列表
-        """
-        # 获取所有元素
-        eles = self.run_script('return arguments[0].querySelectorAll("*")')
-        results = []
-
-        # 遍历所有元素，找到符合条件的
-        for ele in eles:
-            if tag and tag != ele.tag_name:
-                continue
-
-            txt = self.page.driver.execute_script(
-                'if(arguments[0].firstChild!=null){return arguments[0].firstChild.nodeValue}', ele)
-            txt = txt or ''
-
-            # 匹配没有文本的元素或精确匹配
-            if text == '' or match == 'exact':
-                if text == txt:
-
-                    if single:
-                        return DriverElement(ele, self.page)
-                    else:
-                        results.append(DriverElement(ele, self.page))
-
-            # 模糊匹配
-            elif match == 'fuzzy':
-                if text in txt:
-
-                    if single:
-                        return DriverElement(ele, self.page)
-                    else:
-                        results.append(DriverElement(ele, self.page))
-
-        return None if single else results
